bayespy.nodes.Dirichlet
=======================

.. currentmodule:: bayespy.nodes

.. autoclass:: Dirichlet

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Dirichlet.__init__
      ~Dirichlet.add_plate_axis
      ~Dirichlet.broadcasting_multiplier
      ~Dirichlet.delete
      ~Dirichlet.get_gradient
      ~Dirichlet.get_mask
      ~Dirichlet.get_moments
      ~Dirichlet.get_parameters
      ~Dirichlet.get_riemannian_gradient
      ~Dirichlet.get_shape
      ~Dirichlet.has_plotter
      ~Dirichlet.initialize_from_parameters
      ~Dirichlet.initialize_from_prior
      ~Dirichlet.initialize_from_random
      ~Dirichlet.initialize_from_value
      ~Dirichlet.load
      ~Dirichlet.logpdf
      ~Dirichlet.lower_bound_contribution
      ~Dirichlet.lowerbound
      ~Dirichlet.move_plates
      ~Dirichlet.observe
      ~Dirichlet.pdf
      ~Dirichlet.plot
      ~Dirichlet.random
      ~Dirichlet.save
      ~Dirichlet.set_parameters
      ~Dirichlet.set_plotter
      ~Dirichlet.show
      ~Dirichlet.unobserve
      ~Dirichlet.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Dirichlet.dims
      ~Dirichlet.plates
      ~Dirichlet.plates_multiplier
   
   